@@ -90,10 +90,7 @@ class Agent():
         
         
     async def connect(self):
-
-        if not self.herre.logged_in:
-            assert self.auto_login, "Herre is not logged in and auto_login was set to false. Please login with Herre first!"
-            await self.herre.login()
+        assert self.herre.logged_in, "Herre is not logged in and auto_login was set to false. Please login with Herre first!"
 
         if not self.ward.connected:
             assert self.auto_connect, "We have not connected to Arkitekt before and autoconnect was set to false. Please connect a ward before or set auto_connect to True"
@@ -130,6 +127,7 @@ class Agent():
 
 
     def provide(self, as_task=False):
+        assert self.herre.logged_in, "Herre is not logged in and auto_login was set to false. Please login with Herre first!"
         return loopify(self.aprovide(), as_task=as_task)
 
 
