@@ -3,11 +3,11 @@ CURRENT_RPC = None
 CURRENT_AGENT = None
 
 
-def get_current_rpc(force_creation=False):
+def get_current_rpc(force_creation=False, **kwargs):
     global CURRENT_RPC
     if CURRENT_RPC is None and force_creation:
         from arkitekt.rpc import RPC
-        CURRENT_RPC = RPC()
+        CURRENT_RPC = RPC(**kwargs)
     return CURRENT_RPC
 
 
@@ -16,11 +16,11 @@ def set_current_rpc(arkitekt, overwrite=False):
     CURRENT_RPC = arkitekt
 
 
-def get_current_agent(force_creation=False):
+def get_current_agent(force_creation=False, **kwargs):
     global CURRENT_AGENT
     if CURRENT_AGENT is None and force_creation:
         from arkitekt.agents import AppAgent
-        CURRENT_AGENT = AppAgent()
+        CURRENT_AGENT = AppAgent( **kwargs)
     return CURRENT_AGENT
 
 
